@@ -69,7 +69,7 @@ from six import string_types
 from fiona.collection import Collection, BytesCollection, vsi_path
 from fiona._drivers import driver_count, GDALEnv
 from fiona.drvsupport import supported_drivers
-from fiona.odict import OrderedDict
+from fiona.compat import OrderedDict
 from fiona.ogrext import _bounds, _listlayers, FIELD_TYPES_MAP, _remove
 from fiona.ogrext import (
     calc_gdal_version_num, get_gdal_version_num, get_gdal_release_name)
@@ -81,7 +81,7 @@ import uuid
 
 
 __all__ = ['bounds', 'listlayers', 'open', 'prop_type', 'prop_width']
-__version__ = "1.7.0.post2"
+__version__ = "1.7.1"
 __gdal_version__ = get_gdal_release_name().decode('utf-8')
 
 log = logging.getLogger('Fiona')
